# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTMetadataPropertyParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'array': 'bool',
        'name': 'str',
        'id': 'str',
        'description': 'str',
        'namespace': 'str',
        'owner_id': 'str',
        'value_type': 'int',
        'owner_type_ordinal': 'int',
        'property_config_param_list': 'list[BTMetadataPropertyConfigParams]',
        'object_def_name': 'str',
        'blob_mime_type': 'str',
        'editable_in_version': 'bool',
        'editable_in_microversion': 'bool',
        'ui_readonly_in_version': 'bool',
        'ui_readonly_in_microversion': 'bool',
        'search_boost': 'float'
    }

    attribute_map = {
        'array': 'array',
        'name': 'name',
        'id': 'id',
        'description': 'description',
        'namespace': 'namespace',
        'owner_id': 'ownerId',
        'value_type': 'valueType',
        'owner_type_ordinal': 'ownerTypeOrdinal',
        'property_config_param_list': 'propertyConfigParamList',
        'object_def_name': 'objectDefName',
        'blob_mime_type': 'blobMimeType',
        'editable_in_version': 'editableInVersion',
        'editable_in_microversion': 'editableInMicroversion',
        'ui_readonly_in_version': 'uiReadonlyInVersion',
        'ui_readonly_in_microversion': 'uiReadonlyInMicroversion',
        'search_boost': 'searchBoost'
    }

    def __init__(self, array=None, name=None, id=None, description=None, namespace=None, owner_id=None, value_type=None, owner_type_ordinal=None, property_config_param_list=None, object_def_name=None, blob_mime_type=None, editable_in_version=None, editable_in_microversion=None, ui_readonly_in_version=None, ui_readonly_in_microversion=None, search_boost=None):  # noqa: E501
        """BTMetadataPropertyParams - a model defined in OpenAPI"""  # noqa: E501

        self._array = None
        self._name = None
        self._id = None
        self._description = None
        self._namespace = None
        self._owner_id = None
        self._value_type = None
        self._owner_type_ordinal = None
        self._property_config_param_list = None
        self._object_def_name = None
        self._blob_mime_type = None
        self._editable_in_version = None
        self._editable_in_microversion = None
        self._ui_readonly_in_version = None
        self._ui_readonly_in_microversion = None
        self._search_boost = None
        self.discriminator = None

        if array is not None:
            self.array = array
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if description is not None:
            self.description = description
        if namespace is not None:
            self.namespace = namespace
        if owner_id is not None:
            self.owner_id = owner_id
        if value_type is not None:
            self.value_type = value_type
        if owner_type_ordinal is not None:
            self.owner_type_ordinal = owner_type_ordinal
        if property_config_param_list is not None:
            self.property_config_param_list = property_config_param_list
        if object_def_name is not None:
            self.object_def_name = object_def_name
        if blob_mime_type is not None:
            self.blob_mime_type = blob_mime_type
        if editable_in_version is not None:
            self.editable_in_version = editable_in_version
        if editable_in_microversion is not None:
            self.editable_in_microversion = editable_in_microversion
        if ui_readonly_in_version is not None:
            self.ui_readonly_in_version = ui_readonly_in_version
        if ui_readonly_in_microversion is not None:
            self.ui_readonly_in_microversion = ui_readonly_in_microversion
        if search_boost is not None:
            self.search_boost = search_boost

    @property
    def array(self):
        """Gets the array of this BTMetadataPropertyParams.  # noqa: E501


        :return: The array of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: bool
        """
        return self._array

    @array.setter
    def array(self, array):
        """Sets the array of this BTMetadataPropertyParams.


        :param array: The array of this BTMetadataPropertyParams.  # noqa: E501
        :type: bool
        """

        self._array = array

    @property
    def name(self):
        """Gets the name of this BTMetadataPropertyParams.  # noqa: E501


        :return: The name of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTMetadataPropertyParams.


        :param name: The name of this BTMetadataPropertyParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTMetadataPropertyParams.  # noqa: E501


        :return: The id of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTMetadataPropertyParams.


        :param id: The id of this BTMetadataPropertyParams.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def description(self):
        """Gets the description of this BTMetadataPropertyParams.  # noqa: E501


        :return: The description of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTMetadataPropertyParams.


        :param description: The description of this BTMetadataPropertyParams.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def namespace(self):
        """Gets the namespace of this BTMetadataPropertyParams.  # noqa: E501


        :return: The namespace of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BTMetadataPropertyParams.


        :param namespace: The namespace of this BTMetadataPropertyParams.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    @property
    def owner_id(self):
        """Gets the owner_id of this BTMetadataPropertyParams.  # noqa: E501


        :return: The owner_id of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this BTMetadataPropertyParams.


        :param owner_id: The owner_id of this BTMetadataPropertyParams.  # noqa: E501
        :type: str
        """

        self._owner_id = owner_id

    @property
    def value_type(self):
        """Gets the value_type of this BTMetadataPropertyParams.  # noqa: E501


        :return: The value_type of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: int
        """
        return self._value_type

    @value_type.setter
    def value_type(self, value_type):
        """Sets the value_type of this BTMetadataPropertyParams.


        :param value_type: The value_type of this BTMetadataPropertyParams.  # noqa: E501
        :type: int
        """

        self._value_type = value_type

    @property
    def owner_type_ordinal(self):
        """Gets the owner_type_ordinal of this BTMetadataPropertyParams.  # noqa: E501


        :return: The owner_type_ordinal of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: int
        """
        return self._owner_type_ordinal

    @owner_type_ordinal.setter
    def owner_type_ordinal(self, owner_type_ordinal):
        """Sets the owner_type_ordinal of this BTMetadataPropertyParams.


        :param owner_type_ordinal: The owner_type_ordinal of this BTMetadataPropertyParams.  # noqa: E501
        :type: int
        """

        self._owner_type_ordinal = owner_type_ordinal

    @property
    def property_config_param_list(self):
        """Gets the property_config_param_list of this BTMetadataPropertyParams.  # noqa: E501


        :return: The property_config_param_list of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: list[BTMetadataPropertyConfigParams]
        """
        return self._property_config_param_list

    @property_config_param_list.setter
    def property_config_param_list(self, property_config_param_list):
        """Sets the property_config_param_list of this BTMetadataPropertyParams.


        :param property_config_param_list: The property_config_param_list of this BTMetadataPropertyParams.  # noqa: E501
        :type: list[BTMetadataPropertyConfigParams]
        """

        self._property_config_param_list = property_config_param_list

    @property
    def object_def_name(self):
        """Gets the object_def_name of this BTMetadataPropertyParams.  # noqa: E501


        :return: The object_def_name of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: str
        """
        return self._object_def_name

    @object_def_name.setter
    def object_def_name(self, object_def_name):
        """Sets the object_def_name of this BTMetadataPropertyParams.


        :param object_def_name: The object_def_name of this BTMetadataPropertyParams.  # noqa: E501
        :type: str
        """

        self._object_def_name = object_def_name

    @property
    def blob_mime_type(self):
        """Gets the blob_mime_type of this BTMetadataPropertyParams.  # noqa: E501


        :return: The blob_mime_type of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: str
        """
        return self._blob_mime_type

    @blob_mime_type.setter
    def blob_mime_type(self, blob_mime_type):
        """Sets the blob_mime_type of this BTMetadataPropertyParams.


        :param blob_mime_type: The blob_mime_type of this BTMetadataPropertyParams.  # noqa: E501
        :type: str
        """

        self._blob_mime_type = blob_mime_type

    @property
    def editable_in_version(self):
        """Gets the editable_in_version of this BTMetadataPropertyParams.  # noqa: E501


        :return: The editable_in_version of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: bool
        """
        return self._editable_in_version

    @editable_in_version.setter
    def editable_in_version(self, editable_in_version):
        """Sets the editable_in_version of this BTMetadataPropertyParams.


        :param editable_in_version: The editable_in_version of this BTMetadataPropertyParams.  # noqa: E501
        :type: bool
        """

        self._editable_in_version = editable_in_version

    @property
    def editable_in_microversion(self):
        """Gets the editable_in_microversion of this BTMetadataPropertyParams.  # noqa: E501


        :return: The editable_in_microversion of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: bool
        """
        return self._editable_in_microversion

    @editable_in_microversion.setter
    def editable_in_microversion(self, editable_in_microversion):
        """Sets the editable_in_microversion of this BTMetadataPropertyParams.


        :param editable_in_microversion: The editable_in_microversion of this BTMetadataPropertyParams.  # noqa: E501
        :type: bool
        """

        self._editable_in_microversion = editable_in_microversion

    @property
    def ui_readonly_in_version(self):
        """Gets the ui_readonly_in_version of this BTMetadataPropertyParams.  # noqa: E501


        :return: The ui_readonly_in_version of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: bool
        """
        return self._ui_readonly_in_version

    @ui_readonly_in_version.setter
    def ui_readonly_in_version(self, ui_readonly_in_version):
        """Sets the ui_readonly_in_version of this BTMetadataPropertyParams.


        :param ui_readonly_in_version: The ui_readonly_in_version of this BTMetadataPropertyParams.  # noqa: E501
        :type: bool
        """

        self._ui_readonly_in_version = ui_readonly_in_version

    @property
    def ui_readonly_in_microversion(self):
        """Gets the ui_readonly_in_microversion of this BTMetadataPropertyParams.  # noqa: E501


        :return: The ui_readonly_in_microversion of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: bool
        """
        return self._ui_readonly_in_microversion

    @ui_readonly_in_microversion.setter
    def ui_readonly_in_microversion(self, ui_readonly_in_microversion):
        """Sets the ui_readonly_in_microversion of this BTMetadataPropertyParams.


        :param ui_readonly_in_microversion: The ui_readonly_in_microversion of this BTMetadataPropertyParams.  # noqa: E501
        :type: bool
        """

        self._ui_readonly_in_microversion = ui_readonly_in_microversion

    @property
    def search_boost(self):
        """Gets the search_boost of this BTMetadataPropertyParams.  # noqa: E501


        :return: The search_boost of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: float
        """
        return self._search_boost

    @search_boost.setter
    def search_boost(self, search_boost):
        """Sets the search_boost of this BTMetadataPropertyParams.


        :param search_boost: The search_boost of this BTMetadataPropertyParams.  # noqa: E501
        :type: float
        """

        self._search_boost = search_boost

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTMetadataPropertyParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTExportModelParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'microversion': 'str',
        'link_document_id': 'str',
        'configuration': 'str',
        'workspace_id': 'str',
        'element_id': 'str',
        'document_id': 'str',
        'document_version_id': 'str',
        'link_document_workspace_id': 'str',
        'sheet_metal_flat': 'bool',
        'include_bend_lines': 'bool',
        'include_sketches': 'bool',
        'flatten': 'bool',
        'splines_as_polylines': 'bool',
        'is_parting_out': 'bool',
        'include_bend_centerlines': 'bool',
        'batch_flat_patterns': 'bool',
        'scale': 'float',
        'version': 'str',
        'mode': 'str',
        'format': 'str',
        'user_id': 'str',
        'units': 'str',
        'view': 'str',
        'cloud_object_id': 'str',
        'angle_tolerance': 'float',
        'chord_tolerance': 'float',
        'part_ids': 'str',
        'part_query': 'str',
        'max_facet_width': 'float',
        'trigger_auto_download': 'bool',
        'from_user_id': 'str',
        'cloud_storage_account_id': 'str',
        'email_attachment': 'bool',
        'email_link': 'bool',
        'email_subject': 'str',
        'email_message': 'str',
        'email_to': 'list[str]',
        'send_copy_to_me': 'bool',
        'destination_name': 'str',
        'store_in_document': 'bool',
        'element_ids': 'str',
        'include_export_ids': 'bool',
        'feature_ids': 'str',
        'min_facet_width': 'float',
        'resolution': 'str',
        'grouping': 'str',
        'zip_single_file_output': 'bool',
        'include_foreign_data': 'bool',
        'deep_search_for_foreign_data': 'bool',
        'include_std': 'bool',
        'include_release_management_data': 'bool',
        'include_linked_documents': 'bool',
        'extract_to_s3': 'bool'
    }

    attribute_map = {
        'microversion': 'microversion',
        'link_document_id': 'linkDocumentId',
        'configuration': 'configuration',
        'workspace_id': 'workspaceId',
        'element_id': 'elementId',
        'document_id': 'documentId',
        'document_version_id': 'documentVersionId',
        'link_document_workspace_id': 'linkDocumentWorkspaceId',
        'sheet_metal_flat': 'sheetMetalFlat',
        'include_bend_lines': 'includeBendLines',
        'include_sketches': 'includeSketches',
        'flatten': 'flatten',
        'splines_as_polylines': 'splinesAsPolylines',
        'is_parting_out': 'isPartingOut',
        'include_bend_centerlines': 'includeBendCenterlines',
        'batch_flat_patterns': 'batchFlatPatterns',
        'scale': 'scale',
        'version': 'version',
        'mode': 'mode',
        'format': 'format',
        'user_id': 'userId',
        'units': 'units',
        'view': 'view',
        'cloud_object_id': 'cloudObjectId',
        'angle_tolerance': 'angleTolerance',
        'chord_tolerance': 'chordTolerance',
        'part_ids': 'partIds',
        'part_query': 'partQuery',
        'max_facet_width': 'maxFacetWidth',
        'trigger_auto_download': 'triggerAutoDownload',
        'from_user_id': 'fromUserId',
        'cloud_storage_account_id': 'cloudStorageAccountId',
        'email_attachment': 'emailAttachment',
        'email_link': 'emailLink',
        'email_subject': 'emailSubject',
        'email_message': 'emailMessage',
        'email_to': 'emailTo',
        'send_copy_to_me': 'sendCopyToMe',
        'destination_name': 'destinationName',
        'store_in_document': 'storeInDocument',
        'element_ids': 'elementIds',
        'include_export_ids': 'includeExportIds',
        'feature_ids': 'featureIds',
        'min_facet_width': 'minFacetWidth',
        'resolution': 'resolution',
        'grouping': 'grouping',
        'zip_single_file_output': 'zipSingleFileOutput',
        'include_foreign_data': 'includeForeignData',
        'deep_search_for_foreign_data': 'deepSearchForForeignData',
        'include_std': 'includeStd',
        'include_release_management_data': 'includeReleaseManagementData',
        'include_linked_documents': 'includeLinkedDocuments',
        'extract_to_s3': 'extractToS3'
    }

    def __init__(self, microversion=None, link_document_id=None, configuration=None, workspace_id=None, element_id=None, document_id=None, document_version_id=None, link_document_workspace_id=None, sheet_metal_flat=None, include_bend_lines=None, include_sketches=None, flatten=None, splines_as_polylines=None, is_parting_out=None, include_bend_centerlines=None, batch_flat_patterns=None, scale=None, version=None, mode=None, format=None, user_id=None, units=None, view=None, cloud_object_id=None, angle_tolerance=None, chord_tolerance=None, part_ids=None, part_query=None, max_facet_width=None, trigger_auto_download=None, from_user_id=None, cloud_storage_account_id=None, email_attachment=None, email_link=None, email_subject=None, email_message=None, email_to=None, send_copy_to_me=None, destination_name=None, store_in_document=None, element_ids=None, include_export_ids=None, feature_ids=None, min_facet_width=None, resolution=None, grouping=None, zip_single_file_output=None, include_foreign_data=None, deep_search_for_foreign_data=None, include_std=None, include_release_management_data=None, include_linked_documents=None, extract_to_s3=None):  # noqa: E501
        """BTExportModelParams - a model defined in OpenAPI"""  # noqa: E501

        self._microversion = None
        self._link_document_id = None
        self._configuration = None
        self._workspace_id = None
        self._element_id = None
        self._document_id = None
        self._document_version_id = None
        self._link_document_workspace_id = None
        self._sheet_metal_flat = None
        self._include_bend_lines = None
        self._include_sketches = None
        self._flatten = None
        self._splines_as_polylines = None
        self._is_parting_out = None
        self._include_bend_centerlines = None
        self._batch_flat_patterns = None
        self._scale = None
        self._version = None
        self._mode = None
        self._format = None
        self._user_id = None
        self._units = None
        self._view = None
        self._cloud_object_id = None
        self._angle_tolerance = None
        self._chord_tolerance = None
        self._part_ids = None
        self._part_query = None
        self._max_facet_width = None
        self._trigger_auto_download = None
        self._from_user_id = None
        self._cloud_storage_account_id = None
        self._email_attachment = None
        self._email_link = None
        self._email_subject = None
        self._email_message = None
        self._email_to = None
        self._send_copy_to_me = None
        self._destination_name = None
        self._store_in_document = None
        self._element_ids = None
        self._include_export_ids = None
        self._feature_ids = None
        self._min_facet_width = None
        self._resolution = None
        self._grouping = None
        self._zip_single_file_output = None
        self._include_foreign_data = None
        self._deep_search_for_foreign_data = None
        self._include_std = None
        self._include_release_management_data = None
        self._include_linked_documents = None
        self._extract_to_s3 = None
        self.discriminator = None

        if microversion is not None:
            self.microversion = microversion
        if link_document_id is not None:
            self.link_document_id = link_document_id
        if configuration is not None:
            self.configuration = configuration
        if workspace_id is not None:
            self.workspace_id = workspace_id
        if element_id is not None:
            self.element_id = element_id
        if document_id is not None:
            self.document_id = document_id
        if document_version_id is not None:
            self.document_version_id = document_version_id
        if link_document_workspace_id is not None:
            self.link_document_workspace_id = link_document_workspace_id
        if sheet_metal_flat is not None:
            self.sheet_metal_flat = sheet_metal_flat
        if include_bend_lines is not None:
            self.include_bend_lines = include_bend_lines
        if include_sketches is not None:
            self.include_sketches = include_sketches
        if flatten is not None:
            self.flatten = flatten
        if splines_as_polylines is not None:
            self.splines_as_polylines = splines_as_polylines
        if is_parting_out is not None:
            self.is_parting_out = is_parting_out
        if include_bend_centerlines is not None:
            self.include_bend_centerlines = include_bend_centerlines
        if batch_flat_patterns is not None:
            self.batch_flat_patterns = batch_flat_patterns
        if scale is not None:
            self.scale = scale
        if version is not None:
            self.version = version
        if mode is not None:
            self.mode = mode
        if format is not None:
            self.format = format
        if user_id is not None:
            self.user_id = user_id
        if units is not None:
            self.units = units
        if view is not None:
            self.view = view
        if cloud_object_id is not None:
            self.cloud_object_id = cloud_object_id
        if angle_tolerance is not None:
            self.angle_tolerance = angle_tolerance
        if chord_tolerance is not None:
            self.chord_tolerance = chord_tolerance
        if part_ids is not None:
            self.part_ids = part_ids
        if part_query is not None:
            self.part_query = part_query
        if max_facet_width is not None:
            self.max_facet_width = max_facet_width
        if trigger_auto_download is not None:
            self.trigger_auto_download = trigger_auto_download
        if from_user_id is not None:
            self.from_user_id = from_user_id
        if cloud_storage_account_id is not None:
            self.cloud_storage_account_id = cloud_storage_account_id
        if email_attachment is not None:
            self.email_attachment = email_attachment
        if email_link is not None:
            self.email_link = email_link
        if email_subject is not None:
            self.email_subject = email_subject
        if email_message is not None:
            self.email_message = email_message
        if email_to is not None:
            self.email_to = email_to
        if send_copy_to_me is not None:
            self.send_copy_to_me = send_copy_to_me
        if destination_name is not None:
            self.destination_name = destination_name
        if store_in_document is not None:
            self.store_in_document = store_in_document
        if element_ids is not None:
            self.element_ids = element_ids
        if include_export_ids is not None:
            self.include_export_ids = include_export_ids
        if feature_ids is not None:
            self.feature_ids = feature_ids
        if min_facet_width is not None:
            self.min_facet_width = min_facet_width
        if resolution is not None:
            self.resolution = resolution
        if grouping is not None:
            self.grouping = grouping
        if zip_single_file_output is not None:
            self.zip_single_file_output = zip_single_file_output
        if include_foreign_data is not None:
            self.include_foreign_data = include_foreign_data
        if deep_search_for_foreign_data is not None:
            self.deep_search_for_foreign_data = deep_search_for_foreign_data
        if include_std is not None:
            self.include_std = include_std
        if include_release_management_data is not None:
            self.include_release_management_data = include_release_management_data
        if include_linked_documents is not None:
            self.include_linked_documents = include_linked_documents
        if extract_to_s3 is not None:
            self.extract_to_s3 = extract_to_s3

    @property
    def microversion(self):
        """Gets the microversion of this BTExportModelParams.  # noqa: E501


        :return: The microversion of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._microversion

    @microversion.setter
    def microversion(self, microversion):
        """Sets the microversion of this BTExportModelParams.


        :param microversion: The microversion of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._microversion = microversion

    @property
    def link_document_id(self):
        """Gets the link_document_id of this BTExportModelParams.  # noqa: E501


        :return: The link_document_id of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._link_document_id

    @link_document_id.setter
    def link_document_id(self, link_document_id):
        """Sets the link_document_id of this BTExportModelParams.


        :param link_document_id: The link_document_id of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._link_document_id = link_document_id

    @property
    def configuration(self):
        """Gets the configuration of this BTExportModelParams.  # noqa: E501


        :return: The configuration of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this BTExportModelParams.


        :param configuration: The configuration of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._configuration = configuration

    @property
    def workspace_id(self):
        """Gets the workspace_id of this BTExportModelParams.  # noqa: E501


        :return: The workspace_id of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this BTExportModelParams.


        :param workspace_id: The workspace_id of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._workspace_id = workspace_id

    @property
    def element_id(self):
        """Gets the element_id of this BTExportModelParams.  # noqa: E501


        :return: The element_id of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._element_id

    @element_id.setter
    def element_id(self, element_id):
        """Sets the element_id of this BTExportModelParams.


        :param element_id: The element_id of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._element_id = element_id

    @property
    def document_id(self):
        """Gets the document_id of this BTExportModelParams.  # noqa: E501


        :return: The document_id of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTExportModelParams.


        :param document_id: The document_id of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def document_version_id(self):
        """Gets the document_version_id of this BTExportModelParams.  # noqa: E501


        :return: The document_version_id of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._document_version_id

    @document_version_id.setter
    def document_version_id(self, document_version_id):
        """Sets the document_version_id of this BTExportModelParams.


        :param document_version_id: The document_version_id of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._document_version_id = document_version_id

    @property
    def link_document_workspace_id(self):
        """Gets the link_document_workspace_id of this BTExportModelParams.  # noqa: E501


        :return: The link_document_workspace_id of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._link_document_workspace_id

    @link_document_workspace_id.setter
    def link_document_workspace_id(self, link_document_workspace_id):
        """Sets the link_document_workspace_id of this BTExportModelParams.


        :param link_document_workspace_id: The link_document_workspace_id of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._link_document_workspace_id = link_document_workspace_id

    @property
    def sheet_metal_flat(self):
        """Gets the sheet_metal_flat of this BTExportModelParams.  # noqa: E501


        :return: The sheet_metal_flat of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._sheet_metal_flat

    @sheet_metal_flat.setter
    def sheet_metal_flat(self, sheet_metal_flat):
        """Sets the sheet_metal_flat of this BTExportModelParams.


        :param sheet_metal_flat: The sheet_metal_flat of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._sheet_metal_flat = sheet_metal_flat

    @property
    def include_bend_lines(self):
        """Gets the include_bend_lines of this BTExportModelParams.  # noqa: E501


        :return: The include_bend_lines of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._include_bend_lines

    @include_bend_lines.setter
    def include_bend_lines(self, include_bend_lines):
        """Sets the include_bend_lines of this BTExportModelParams.


        :param include_bend_lines: The include_bend_lines of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._include_bend_lines = include_bend_lines

    @property
    def include_sketches(self):
        """Gets the include_sketches of this BTExportModelParams.  # noqa: E501


        :return: The include_sketches of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._include_sketches

    @include_sketches.setter
    def include_sketches(self, include_sketches):
        """Sets the include_sketches of this BTExportModelParams.


        :param include_sketches: The include_sketches of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._include_sketches = include_sketches

    @property
    def flatten(self):
        """Gets the flatten of this BTExportModelParams.  # noqa: E501


        :return: The flatten of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._flatten

    @flatten.setter
    def flatten(self, flatten):
        """Sets the flatten of this BTExportModelParams.


        :param flatten: The flatten of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._flatten = flatten

    @property
    def splines_as_polylines(self):
        """Gets the splines_as_polylines of this BTExportModelParams.  # noqa: E501


        :return: The splines_as_polylines of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._splines_as_polylines

    @splines_as_polylines.setter
    def splines_as_polylines(self, splines_as_polylines):
        """Sets the splines_as_polylines of this BTExportModelParams.


        :param splines_as_polylines: The splines_as_polylines of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._splines_as_polylines = splines_as_polylines

    @property
    def is_parting_out(self):
        """Gets the is_parting_out of this BTExportModelParams.  # noqa: E501


        :return: The is_parting_out of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_parting_out

    @is_parting_out.setter
    def is_parting_out(self, is_parting_out):
        """Sets the is_parting_out of this BTExportModelParams.


        :param is_parting_out: The is_parting_out of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._is_parting_out = is_parting_out

    @property
    def include_bend_centerlines(self):
        """Gets the include_bend_centerlines of this BTExportModelParams.  # noqa: E501


        :return: The include_bend_centerlines of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._include_bend_centerlines

    @include_bend_centerlines.setter
    def include_bend_centerlines(self, include_bend_centerlines):
        """Sets the include_bend_centerlines of this BTExportModelParams.


        :param include_bend_centerlines: The include_bend_centerlines of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._include_bend_centerlines = include_bend_centerlines

    @property
    def batch_flat_patterns(self):
        """Gets the batch_flat_patterns of this BTExportModelParams.  # noqa: E501


        :return: The batch_flat_patterns of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._batch_flat_patterns

    @batch_flat_patterns.setter
    def batch_flat_patterns(self, batch_flat_patterns):
        """Sets the batch_flat_patterns of this BTExportModelParams.


        :param batch_flat_patterns: The batch_flat_patterns of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._batch_flat_patterns = batch_flat_patterns

    @property
    def scale(self):
        """Gets the scale of this BTExportModelParams.  # noqa: E501


        :return: The scale of this BTExportModelParams.  # noqa: E501
        :rtype: float
        """
        return self._scale

    @scale.setter
    def scale(self, scale):
        """Sets the scale of this BTExportModelParams.


        :param scale: The scale of this BTExportModelParams.  # noqa: E501
        :type: float
        """

        self._scale = scale

    @property
    def version(self):
        """Gets the version of this BTExportModelParams.  # noqa: E501


        :return: The version of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this BTExportModelParams.


        :param version: The version of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def mode(self):
        """Gets the mode of this BTExportModelParams.  # noqa: E501


        :return: The mode of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this BTExportModelParams.


        :param mode: The mode of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._mode = mode

    @property
    def format(self):
        """Gets the format of this BTExportModelParams.  # noqa: E501


        :return: The format of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this BTExportModelParams.


        :param format: The format of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def user_id(self):
        """Gets the user_id of this BTExportModelParams.  # noqa: E501


        :return: The user_id of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this BTExportModelParams.


        :param user_id: The user_id of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def units(self):
        """Gets the units of this BTExportModelParams.  # noqa: E501


        :return: The units of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this BTExportModelParams.


        :param units: The units of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._units = units

    @property
    def view(self):
        """Gets the view of this BTExportModelParams.  # noqa: E501


        :return: The view of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._view

    @view.setter
    def view(self, view):
        """Sets the view of this BTExportModelParams.


        :param view: The view of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._view = view

    @property
    def cloud_object_id(self):
        """Gets the cloud_object_id of this BTExportModelParams.  # noqa: E501


        :return: The cloud_object_id of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._cloud_object_id

    @cloud_object_id.setter
    def cloud_object_id(self, cloud_object_id):
        """Sets the cloud_object_id of this BTExportModelParams.


        :param cloud_object_id: The cloud_object_id of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._cloud_object_id = cloud_object_id

    @property
    def angle_tolerance(self):
        """Gets the angle_tolerance of this BTExportModelParams.  # noqa: E501


        :return: The angle_tolerance of this BTExportModelParams.  # noqa: E501
        :rtype: float
        """
        return self._angle_tolerance

    @angle_tolerance.setter
    def angle_tolerance(self, angle_tolerance):
        """Sets the angle_tolerance of this BTExportModelParams.


        :param angle_tolerance: The angle_tolerance of this BTExportModelParams.  # noqa: E501
        :type: float
        """

        self._angle_tolerance = angle_tolerance

    @property
    def chord_tolerance(self):
        """Gets the chord_tolerance of this BTExportModelParams.  # noqa: E501


        :return: The chord_tolerance of this BTExportModelParams.  # noqa: E501
        :rtype: float
        """
        return self._chord_tolerance

    @chord_tolerance.setter
    def chord_tolerance(self, chord_tolerance):
        """Sets the chord_tolerance of this BTExportModelParams.


        :param chord_tolerance: The chord_tolerance of this BTExportModelParams.  # noqa: E501
        :type: float
        """

        self._chord_tolerance = chord_tolerance

    @property
    def part_ids(self):
        """Gets the part_ids of this BTExportModelParams.  # noqa: E501


        :return: The part_ids of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._part_ids

    @part_ids.setter
    def part_ids(self, part_ids):
        """Sets the part_ids of this BTExportModelParams.


        :param part_ids: The part_ids of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._part_ids = part_ids

    @property
    def part_query(self):
        """Gets the part_query of this BTExportModelParams.  # noqa: E501


        :return: The part_query of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._part_query

    @part_query.setter
    def part_query(self, part_query):
        """Sets the part_query of this BTExportModelParams.


        :param part_query: The part_query of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._part_query = part_query

    @property
    def max_facet_width(self):
        """Gets the max_facet_width of this BTExportModelParams.  # noqa: E501


        :return: The max_facet_width of this BTExportModelParams.  # noqa: E501
        :rtype: float
        """
        return self._max_facet_width

    @max_facet_width.setter
    def max_facet_width(self, max_facet_width):
        """Sets the max_facet_width of this BTExportModelParams.


        :param max_facet_width: The max_facet_width of this BTExportModelParams.  # noqa: E501
        :type: float
        """

        self._max_facet_width = max_facet_width

    @property
    def trigger_auto_download(self):
        """Gets the trigger_auto_download of this BTExportModelParams.  # noqa: E501


        :return: The trigger_auto_download of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._trigger_auto_download

    @trigger_auto_download.setter
    def trigger_auto_download(self, trigger_auto_download):
        """Sets the trigger_auto_download of this BTExportModelParams.


        :param trigger_auto_download: The trigger_auto_download of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._trigger_auto_download = trigger_auto_download

    @property
    def from_user_id(self):
        """Gets the from_user_id of this BTExportModelParams.  # noqa: E501


        :return: The from_user_id of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._from_user_id

    @from_user_id.setter
    def from_user_id(self, from_user_id):
        """Sets the from_user_id of this BTExportModelParams.


        :param from_user_id: The from_user_id of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._from_user_id = from_user_id

    @property
    def cloud_storage_account_id(self):
        """Gets the cloud_storage_account_id of this BTExportModelParams.  # noqa: E501


        :return: The cloud_storage_account_id of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._cloud_storage_account_id

    @cloud_storage_account_id.setter
    def cloud_storage_account_id(self, cloud_storage_account_id):
        """Sets the cloud_storage_account_id of this BTExportModelParams.


        :param cloud_storage_account_id: The cloud_storage_account_id of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._cloud_storage_account_id = cloud_storage_account_id

    @property
    def email_attachment(self):
        """Gets the email_attachment of this BTExportModelParams.  # noqa: E501


        :return: The email_attachment of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._email_attachment

    @email_attachment.setter
    def email_attachment(self, email_attachment):
        """Sets the email_attachment of this BTExportModelParams.


        :param email_attachment: The email_attachment of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._email_attachment = email_attachment

    @property
    def email_link(self):
        """Gets the email_link of this BTExportModelParams.  # noqa: E501


        :return: The email_link of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._email_link

    @email_link.setter
    def email_link(self, email_link):
        """Sets the email_link of this BTExportModelParams.


        :param email_link: The email_link of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._email_link = email_link

    @property
    def email_subject(self):
        """Gets the email_subject of this BTExportModelParams.  # noqa: E501


        :return: The email_subject of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._email_subject

    @email_subject.setter
    def email_subject(self, email_subject):
        """Sets the email_subject of this BTExportModelParams.


        :param email_subject: The email_subject of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._email_subject = email_subject

    @property
    def email_message(self):
        """Gets the email_message of this BTExportModelParams.  # noqa: E501


        :return: The email_message of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._email_message

    @email_message.setter
    def email_message(self, email_message):
        """Sets the email_message of this BTExportModelParams.


        :param email_message: The email_message of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._email_message = email_message

    @property
    def email_to(self):
        """Gets the email_to of this BTExportModelParams.  # noqa: E501


        :return: The email_to of this BTExportModelParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._email_to

    @email_to.setter
    def email_to(self, email_to):
        """Sets the email_to of this BTExportModelParams.


        :param email_to: The email_to of this BTExportModelParams.  # noqa: E501
        :type: list[str]
        """

        self._email_to = email_to

    @property
    def send_copy_to_me(self):
        """Gets the send_copy_to_me of this BTExportModelParams.  # noqa: E501


        :return: The send_copy_to_me of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._send_copy_to_me

    @send_copy_to_me.setter
    def send_copy_to_me(self, send_copy_to_me):
        """Sets the send_copy_to_me of this BTExportModelParams.


        :param send_copy_to_me: The send_copy_to_me of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._send_copy_to_me = send_copy_to_me

    @property
    def destination_name(self):
        """Gets the destination_name of this BTExportModelParams.  # noqa: E501


        :return: The destination_name of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._destination_name

    @destination_name.setter
    def destination_name(self, destination_name):
        """Sets the destination_name of this BTExportModelParams.


        :param destination_name: The destination_name of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._destination_name = destination_name

    @property
    def store_in_document(self):
        """Gets the store_in_document of this BTExportModelParams.  # noqa: E501


        :return: The store_in_document of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._store_in_document

    @store_in_document.setter
    def store_in_document(self, store_in_document):
        """Sets the store_in_document of this BTExportModelParams.


        :param store_in_document: The store_in_document of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._store_in_document = store_in_document

    @property
    def element_ids(self):
        """Gets the element_ids of this BTExportModelParams.  # noqa: E501


        :return: The element_ids of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._element_ids

    @element_ids.setter
    def element_ids(self, element_ids):
        """Sets the element_ids of this BTExportModelParams.


        :param element_ids: The element_ids of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._element_ids = element_ids

    @property
    def include_export_ids(self):
        """Gets the include_export_ids of this BTExportModelParams.  # noqa: E501


        :return: The include_export_ids of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._include_export_ids

    @include_export_ids.setter
    def include_export_ids(self, include_export_ids):
        """Sets the include_export_ids of this BTExportModelParams.


        :param include_export_ids: The include_export_ids of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._include_export_ids = include_export_ids

    @property
    def feature_ids(self):
        """Gets the feature_ids of this BTExportModelParams.  # noqa: E501


        :return: The feature_ids of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._feature_ids

    @feature_ids.setter
    def feature_ids(self, feature_ids):
        """Sets the feature_ids of this BTExportModelParams.


        :param feature_ids: The feature_ids of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._feature_ids = feature_ids

    @property
    def min_facet_width(self):
        """Gets the min_facet_width of this BTExportModelParams.  # noqa: E501


        :return: The min_facet_width of this BTExportModelParams.  # noqa: E501
        :rtype: float
        """
        return self._min_facet_width

    @min_facet_width.setter
    def min_facet_width(self, min_facet_width):
        """Sets the min_facet_width of this BTExportModelParams.


        :param min_facet_width: The min_facet_width of this BTExportModelParams.  # noqa: E501
        :type: float
        """

        self._min_facet_width = min_facet_width

    @property
    def resolution(self):
        """Gets the resolution of this BTExportModelParams.  # noqa: E501


        :return: The resolution of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._resolution

    @resolution.setter
    def resolution(self, resolution):
        """Sets the resolution of this BTExportModelParams.


        :param resolution: The resolution of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._resolution = resolution

    @property
    def grouping(self):
        """Gets the grouping of this BTExportModelParams.  # noqa: E501


        :return: The grouping of this BTExportModelParams.  # noqa: E501
        :rtype: str
        """
        return self._grouping

    @grouping.setter
    def grouping(self, grouping):
        """Sets the grouping of this BTExportModelParams.


        :param grouping: The grouping of this BTExportModelParams.  # noqa: E501
        :type: str
        """

        self._grouping = grouping

    @property
    def zip_single_file_output(self):
        """Gets the zip_single_file_output of this BTExportModelParams.  # noqa: E501


        :return: The zip_single_file_output of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._zip_single_file_output

    @zip_single_file_output.setter
    def zip_single_file_output(self, zip_single_file_output):
        """Sets the zip_single_file_output of this BTExportModelParams.


        :param zip_single_file_output: The zip_single_file_output of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._zip_single_file_output = zip_single_file_output

    @property
    def include_foreign_data(self):
        """Gets the include_foreign_data of this BTExportModelParams.  # noqa: E501


        :return: The include_foreign_data of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._include_foreign_data

    @include_foreign_data.setter
    def include_foreign_data(self, include_foreign_data):
        """Sets the include_foreign_data of this BTExportModelParams.


        :param include_foreign_data: The include_foreign_data of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._include_foreign_data = include_foreign_data

    @property
    def deep_search_for_foreign_data(self):
        """Gets the deep_search_for_foreign_data of this BTExportModelParams.  # noqa: E501


        :return: The deep_search_for_foreign_data of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._deep_search_for_foreign_data

    @deep_search_for_foreign_data.setter
    def deep_search_for_foreign_data(self, deep_search_for_foreign_data):
        """Sets the deep_search_for_foreign_data of this BTExportModelParams.


        :param deep_search_for_foreign_data: The deep_search_for_foreign_data of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._deep_search_for_foreign_data = deep_search_for_foreign_data

    @property
    def include_std(self):
        """Gets the include_std of this BTExportModelParams.  # noqa: E501


        :return: The include_std of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._include_std

    @include_std.setter
    def include_std(self, include_std):
        """Sets the include_std of this BTExportModelParams.


        :param include_std: The include_std of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._include_std = include_std

    @property
    def include_release_management_data(self):
        """Gets the include_release_management_data of this BTExportModelParams.  # noqa: E501


        :return: The include_release_management_data of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._include_release_management_data

    @include_release_management_data.setter
    def include_release_management_data(self, include_release_management_data):
        """Sets the include_release_management_data of this BTExportModelParams.


        :param include_release_management_data: The include_release_management_data of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._include_release_management_data = include_release_management_data

    @property
    def include_linked_documents(self):
        """Gets the include_linked_documents of this BTExportModelParams.  # noqa: E501


        :return: The include_linked_documents of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._include_linked_documents

    @include_linked_documents.setter
    def include_linked_documents(self, include_linked_documents):
        """Sets the include_linked_documents of this BTExportModelParams.


        :param include_linked_documents: The include_linked_documents of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._include_linked_documents = include_linked_documents

    @property
    def extract_to_s3(self):
        """Gets the extract_to_s3 of this BTExportModelParams.  # noqa: E501


        :return: The extract_to_s3 of this BTExportModelParams.  # noqa: E501
        :rtype: bool
        """
        return self._extract_to_s3

    @extract_to_s3.setter
    def extract_to_s3(self, extract_to_s3):
        """Sets the extract_to_s3 of this BTExportModelParams.


        :param extract_to_s3: The extract_to_s3 of this BTExportModelParams.  # noqa: E501
        :type: bool
        """

        self._extract_to_s3 = extract_to_s3

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTExportModelParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTWorkflowableTestObjectInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'info': 'dict(str, str)',
        'properties': 'list[BTWorkflowPropertyInfo]',
        'description_as_property': 'str',
        'name_as_property': 'str',
        'description': 'str',
        'workflow': 'BTWorkflowSnapshotInfo',
        'company_id': 'str',
        'document_id': 'str',
        'is_obsoletion': 'bool',
        'name': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str'
    }

    attribute_map = {
        'info': 'info',
        'properties': 'properties',
        'description_as_property': 'descriptionAsProperty',
        'name_as_property': 'nameAsProperty',
        'description': 'description',
        'workflow': 'workflow',
        'company_id': 'companyId',
        'document_id': 'documentId',
        'is_obsoletion': 'isObsoletion',
        'name': 'name',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef'
    }

    def __init__(self, info=None, properties=None, description_as_property=None, name_as_property=None, description=None, workflow=None, company_id=None, document_id=None, is_obsoletion=None, name=None, id=None, href=None, view_ref=None):  # noqa: E501
        """BTWorkflowableTestObjectInfo - a model defined in OpenAPI"""  # noqa: E501

        self._info = None
        self._properties = None
        self._description_as_property = None
        self._name_as_property = None
        self._description = None
        self._workflow = None
        self._company_id = None
        self._document_id = None
        self._is_obsoletion = None
        self._name = None
        self._id = None
        self._href = None
        self._view_ref = None
        self.discriminator = None

        if info is not None:
            self.info = info
        if properties is not None:
            self.properties = properties
        if description_as_property is not None:
            self.description_as_property = description_as_property
        if name_as_property is not None:
            self.name_as_property = name_as_property
        if description is not None:
            self.description = description
        if workflow is not None:
            self.workflow = workflow
        if company_id is not None:
            self.company_id = company_id
        if document_id is not None:
            self.document_id = document_id
        if is_obsoletion is not None:
            self.is_obsoletion = is_obsoletion
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref

    @property
    def info(self):
        """Gets the info of this BTWorkflowableTestObjectInfo.  # noqa: E501


        :return: The info of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._info

    @info.setter
    def info(self, info):
        """Sets the info of this BTWorkflowableTestObjectInfo.


        :param info: The info of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :type: dict(str, str)
        """

        self._info = info

    @property
    def properties(self):
        """Gets the properties of this BTWorkflowableTestObjectInfo.  # noqa: E501


        :return: The properties of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :rtype: list[BTWorkflowPropertyInfo]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this BTWorkflowableTestObjectInfo.


        :param properties: The properties of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :type: list[BTWorkflowPropertyInfo]
        """

        self._properties = properties

    @property
    def description_as_property(self):
        """Gets the description_as_property of this BTWorkflowableTestObjectInfo.  # noqa: E501


        :return: The description_as_property of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._description_as_property

    @description_as_property.setter
    def description_as_property(self, description_as_property):
        """Sets the description_as_property of this BTWorkflowableTestObjectInfo.


        :param description_as_property: The description_as_property of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :type: str
        """

        self._description_as_property = description_as_property

    @property
    def name_as_property(self):
        """Gets the name_as_property of this BTWorkflowableTestObjectInfo.  # noqa: E501


        :return: The name_as_property of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._name_as_property

    @name_as_property.setter
    def name_as_property(self, name_as_property):
        """Sets the name_as_property of this BTWorkflowableTestObjectInfo.


        :param name_as_property: The name_as_property of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :type: str
        """

        self._name_as_property = name_as_property

    @property
    def description(self):
        """Gets the description of this BTWorkflowableTestObjectInfo.  # noqa: E501


        :return: The description of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTWorkflowableTestObjectInfo.


        :param description: The description of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def workflow(self):
        """Gets the workflow of this BTWorkflowableTestObjectInfo.  # noqa: E501


        :return: The workflow of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :rtype: BTWorkflowSnapshotInfo
        """
        return self._workflow

    @workflow.setter
    def workflow(self, workflow):
        """Sets the workflow of this BTWorkflowableTestObjectInfo.


        :param workflow: The workflow of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :type: BTWorkflowSnapshotInfo
        """

        self._workflow = workflow

    @property
    def company_id(self):
        """Gets the company_id of this BTWorkflowableTestObjectInfo.  # noqa: E501


        :return: The company_id of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._company_id

    @company_id.setter
    def company_id(self, company_id):
        """Sets the company_id of this BTWorkflowableTestObjectInfo.


        :param company_id: The company_id of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :type: str
        """

        self._company_id = company_id

    @property
    def document_id(self):
        """Gets the document_id of this BTWorkflowableTestObjectInfo.  # noqa: E501


        :return: The document_id of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTWorkflowableTestObjectInfo.


        :param document_id: The document_id of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def is_obsoletion(self):
        """Gets the is_obsoletion of this BTWorkflowableTestObjectInfo.  # noqa: E501


        :return: The is_obsoletion of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_obsoletion

    @is_obsoletion.setter
    def is_obsoletion(self, is_obsoletion):
        """Sets the is_obsoletion of this BTWorkflowableTestObjectInfo.


        :param is_obsoletion: The is_obsoletion of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :type: bool
        """

        self._is_obsoletion = is_obsoletion

    @property
    def name(self):
        """Gets the name of this BTWorkflowableTestObjectInfo.  # noqa: E501


        :return: The name of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTWorkflowableTestObjectInfo.


        :param name: The name of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTWorkflowableTestObjectInfo.  # noqa: E501


        :return: The id of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTWorkflowableTestObjectInfo.


        :param id: The id of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTWorkflowableTestObjectInfo.  # noqa: E501


        :return: The href of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTWorkflowableTestObjectInfo.


        :param href: The href of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTWorkflowableTestObjectInfo.  # noqa: E501


        :return: The view_ref of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTWorkflowableTestObjectInfo.


        :param view_ref: The view_ref of this BTWorkflowableTestObjectInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTWorkflowableTestObjectInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTMetadataPropertyConfigParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'default_value': 'str',
        'display_name': 'str',
        'pattern': 'str',
        'property_id': 'str',
        'required': 'bool',
        'publish_state': 'int',
        'schema_id': 'str',
        'min_length': 'int',
        'max_length': 'int',
        'min_value': 'float',
        'max_value': 'float',
        'min_date': 'datetime',
        'max_date': 'datetime',
        'min_count': 'int',
        'max_count': 'int',
        'multiline': 'bool',
        'enum_values': 'list[dict(str, str)]'
    }

    attribute_map = {
        'default_value': 'defaultValue',
        'display_name': 'displayName',
        'pattern': 'pattern',
        'property_id': 'propertyId',
        'required': 'required',
        'publish_state': 'publishState',
        'schema_id': 'schemaId',
        'min_length': 'minLength',
        'max_length': 'maxLength',
        'min_value': 'minValue',
        'max_value': 'maxValue',
        'min_date': 'minDate',
        'max_date': 'maxDate',
        'min_count': 'minCount',
        'max_count': 'maxCount',
        'multiline': 'multiline',
        'enum_values': 'enumValues'
    }

    def __init__(self, default_value=None, display_name=None, pattern=None, property_id=None, required=None, publish_state=None, schema_id=None, min_length=None, max_length=None, min_value=None, max_value=None, min_date=None, max_date=None, min_count=None, max_count=None, multiline=None, enum_values=None):  # noqa: E501
        """BTMetadataPropertyConfigParams - a model defined in OpenAPI"""  # noqa: E501

        self._default_value = None
        self._display_name = None
        self._pattern = None
        self._property_id = None
        self._required = None
        self._publish_state = None
        self._schema_id = None
        self._min_length = None
        self._max_length = None
        self._min_value = None
        self._max_value = None
        self._min_date = None
        self._max_date = None
        self._min_count = None
        self._max_count = None
        self._multiline = None
        self._enum_values = None
        self.discriminator = None

        if default_value is not None:
            self.default_value = default_value
        if display_name is not None:
            self.display_name = display_name
        if pattern is not None:
            self.pattern = pattern
        if property_id is not None:
            self.property_id = property_id
        if required is not None:
            self.required = required
        if publish_state is not None:
            self.publish_state = publish_state
        if schema_id is not None:
            self.schema_id = schema_id
        if min_length is not None:
            self.min_length = min_length
        if max_length is not None:
            self.max_length = max_length
        if min_value is not None:
            self.min_value = min_value
        if max_value is not None:
            self.max_value = max_value
        if min_date is not None:
            self.min_date = min_date
        if max_date is not None:
            self.max_date = max_date
        if min_count is not None:
            self.min_count = min_count
        if max_count is not None:
            self.max_count = max_count
        if multiline is not None:
            self.multiline = multiline
        if enum_values is not None:
            self.enum_values = enum_values

    @property
    def default_value(self):
        """Gets the default_value of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The default_value of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: str
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """Sets the default_value of this BTMetadataPropertyConfigParams.


        :param default_value: The default_value of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: str
        """

        self._default_value = default_value

    @property
    def display_name(self):
        """Gets the display_name of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The display_name of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this BTMetadataPropertyConfigParams.


        :param display_name: The display_name of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def pattern(self):
        """Gets the pattern of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The pattern of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """Sets the pattern of this BTMetadataPropertyConfigParams.


        :param pattern: The pattern of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: str
        """

        self._pattern = pattern

    @property
    def property_id(self):
        """Gets the property_id of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The property_id of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: str
        """
        return self._property_id

    @property_id.setter
    def property_id(self, property_id):
        """Sets the property_id of this BTMetadataPropertyConfigParams.


        :param property_id: The property_id of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: str
        """

        self._property_id = property_id

    @property
    def required(self):
        """Gets the required of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The required of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this BTMetadataPropertyConfigParams.


        :param required: The required of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: bool
        """

        self._required = required

    @property
    def publish_state(self):
        """Gets the publish_state of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The publish_state of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: int
        """
        return self._publish_state

    @publish_state.setter
    def publish_state(self, publish_state):
        """Sets the publish_state of this BTMetadataPropertyConfigParams.


        :param publish_state: The publish_state of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: int
        """

        self._publish_state = publish_state

    @property
    def schema_id(self):
        """Gets the schema_id of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The schema_id of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: str
        """
        return self._schema_id

    @schema_id.setter
    def schema_id(self, schema_id):
        """Sets the schema_id of this BTMetadataPropertyConfigParams.


        :param schema_id: The schema_id of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: str
        """

        self._schema_id = schema_id

    @property
    def min_length(self):
        """Gets the min_length of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The min_length of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: int
        """
        return self._min_length

    @min_length.setter
    def min_length(self, min_length):
        """Sets the min_length of this BTMetadataPropertyConfigParams.


        :param min_length: The min_length of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: int
        """

        self._min_length = min_length

    @property
    def max_length(self):
        """Gets the max_length of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The max_length of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: int
        """
        return self._max_length

    @max_length.setter
    def max_length(self, max_length):
        """Sets the max_length of this BTMetadataPropertyConfigParams.


        :param max_length: The max_length of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: int
        """

        self._max_length = max_length

    @property
    def min_value(self):
        """Gets the min_value of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The min_value of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: float
        """
        return self._min_value

    @min_value.setter
    def min_value(self, min_value):
        """Sets the min_value of this BTMetadataPropertyConfigParams.


        :param min_value: The min_value of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: float
        """

        self._min_value = min_value

    @property
    def max_value(self):
        """Gets the max_value of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The max_value of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: float
        """
        return self._max_value

    @max_value.setter
    def max_value(self, max_value):
        """Sets the max_value of this BTMetadataPropertyConfigParams.


        :param max_value: The max_value of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: float
        """

        self._max_value = max_value

    @property
    def min_date(self):
        """Gets the min_date of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The min_date of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: datetime
        """
        return self._min_date

    @min_date.setter
    def min_date(self, min_date):
        """Sets the min_date of this BTMetadataPropertyConfigParams.


        :param min_date: The min_date of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: datetime
        """

        self._min_date = min_date

    @property
    def max_date(self):
        """Gets the max_date of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The max_date of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: datetime
        """
        return self._max_date

    @max_date.setter
    def max_date(self, max_date):
        """Sets the max_date of this BTMetadataPropertyConfigParams.


        :param max_date: The max_date of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: datetime
        """

        self._max_date = max_date

    @property
    def min_count(self):
        """Gets the min_count of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The min_count of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: int
        """
        return self._min_count

    @min_count.setter
    def min_count(self, min_count):
        """Sets the min_count of this BTMetadataPropertyConfigParams.


        :param min_count: The min_count of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: int
        """

        self._min_count = min_count

    @property
    def max_count(self):
        """Gets the max_count of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The max_count of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: int
        """
        return self._max_count

    @max_count.setter
    def max_count(self, max_count):
        """Sets the max_count of this BTMetadataPropertyConfigParams.


        :param max_count: The max_count of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: int
        """

        self._max_count = max_count

    @property
    def multiline(self):
        """Gets the multiline of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The multiline of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: bool
        """
        return self._multiline

    @multiline.setter
    def multiline(self, multiline):
        """Sets the multiline of this BTMetadataPropertyConfigParams.


        :param multiline: The multiline of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: bool
        """

        self._multiline = multiline

    @property
    def enum_values(self):
        """Gets the enum_values of this BTMetadataPropertyConfigParams.  # noqa: E501


        :return: The enum_values of this BTMetadataPropertyConfigParams.  # noqa: E501
        :rtype: list[dict(str, str)]
        """
        return self._enum_values

    @enum_values.setter
    def enum_values(self, enum_values):
        """Sets the enum_values of this BTMetadataPropertyConfigParams.


        :param enum_values: The enum_values of this BTMetadataPropertyConfigParams.  # noqa: E501
        :type: list[dict(str, str)]
        """

        self._enum_values = enum_values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTMetadataPropertyConfigParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTShareParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'message': 'str',
        'entries': 'list[BTShareEntryParams]',
        'permission': 'int',
        'workspace_id': 'str',
        'element_id': 'str',
        'folder_id': 'str',
        'permission_set': 'BTPermissionSet',
        'document_id': 'str',
        'update': 'bool',
        'encoded_configuration': 'str'
    }

    attribute_map = {
        'message': 'message',
        'entries': 'entries',
        'permission': 'permission',
        'workspace_id': 'workspaceId',
        'element_id': 'elementId',
        'folder_id': 'folderId',
        'permission_set': 'permissionSet',
        'document_id': 'documentId',
        'update': 'update',
        'encoded_configuration': 'encodedConfiguration'
    }

    def __init__(self, message=None, entries=None, permission=None, workspace_id=None, element_id=None, folder_id=None, permission_set=None, document_id=None, update=None, encoded_configuration=None):  # noqa: E501
        """BTShareParams - a model defined in OpenAPI"""  # noqa: E501

        self._message = None
        self._entries = None
        self._permission = None
        self._workspace_id = None
        self._element_id = None
        self._folder_id = None
        self._permission_set = None
        self._document_id = None
        self._update = None
        self._encoded_configuration = None
        self.discriminator = None

        if message is not None:
            self.message = message
        if entries is not None:
            self.entries = entries
        if permission is not None:
            self.permission = permission
        if workspace_id is not None:
            self.workspace_id = workspace_id
        if element_id is not None:
            self.element_id = element_id
        if folder_id is not None:
            self.folder_id = folder_id
        if permission_set is not None:
            self.permission_set = permission_set
        if document_id is not None:
            self.document_id = document_id
        if update is not None:
            self.update = update
        if encoded_configuration is not None:
            self.encoded_configuration = encoded_configuration

    @property
    def message(self):
        """Gets the message of this BTShareParams.  # noqa: E501


        :return: The message of this BTShareParams.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this BTShareParams.


        :param message: The message of this BTShareParams.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def entries(self):
        """Gets the entries of this BTShareParams.  # noqa: E501


        :return: The entries of this BTShareParams.  # noqa: E501
        :rtype: list[BTShareEntryParams]
        """
        return self._entries

    @entries.setter
    def entries(self, entries):
        """Sets the entries of this BTShareParams.


        :param entries: The entries of this BTShareParams.  # noqa: E501
        :type: list[BTShareEntryParams]
        """

        self._entries = entries

    @property
    def permission(self):
        """Gets the permission of this BTShareParams.  # noqa: E501


        :return: The permission of this BTShareParams.  # noqa: E501
        :rtype: int
        """
        return self._permission

    @permission.setter
    def permission(self, permission):
        """Sets the permission of this BTShareParams.


        :param permission: The permission of this BTShareParams.  # noqa: E501
        :type: int
        """

        self._permission = permission

    @property
    def workspace_id(self):
        """Gets the workspace_id of this BTShareParams.  # noqa: E501


        :return: The workspace_id of this BTShareParams.  # noqa: E501
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this BTShareParams.


        :param workspace_id: The workspace_id of this BTShareParams.  # noqa: E501
        :type: str
        """

        self._workspace_id = workspace_id

    @property
    def element_id(self):
        """Gets the element_id of this BTShareParams.  # noqa: E501


        :return: The element_id of this BTShareParams.  # noqa: E501
        :rtype: str
        """
        return self._element_id

    @element_id.setter
    def element_id(self, element_id):
        """Sets the element_id of this BTShareParams.


        :param element_id: The element_id of this BTShareParams.  # noqa: E501
        :type: str
        """

        self._element_id = element_id

    @property
    def folder_id(self):
        """Gets the folder_id of this BTShareParams.  # noqa: E501


        :return: The folder_id of this BTShareParams.  # noqa: E501
        :rtype: str
        """
        return self._folder_id

    @folder_id.setter
    def folder_id(self, folder_id):
        """Sets the folder_id of this BTShareParams.


        :param folder_id: The folder_id of this BTShareParams.  # noqa: E501
        :type: str
        """

        self._folder_id = folder_id

    @property
    def permission_set(self):
        """Gets the permission_set of this BTShareParams.  # noqa: E501


        :return: The permission_set of this BTShareParams.  # noqa: E501
        :rtype: BTPermissionSet
        """
        return self._permission_set

    @permission_set.setter
    def permission_set(self, permission_set):
        """Sets the permission_set of this BTShareParams.


        :param permission_set: The permission_set of this BTShareParams.  # noqa: E501
        :type: BTPermissionSet
        """

        self._permission_set = permission_set

    @property
    def document_id(self):
        """Gets the document_id of this BTShareParams.  # noqa: E501


        :return: The document_id of this BTShareParams.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTShareParams.


        :param document_id: The document_id of this BTShareParams.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def update(self):
        """Gets the update of this BTShareParams.  # noqa: E501


        :return: The update of this BTShareParams.  # noqa: E501
        :rtype: bool
        """
        return self._update

    @update.setter
    def update(self, update):
        """Sets the update of this BTShareParams.


        :param update: The update of this BTShareParams.  # noqa: E501
        :type: bool
        """

        self._update = update

    @property
    def encoded_configuration(self):
        """Gets the encoded_configuration of this BTShareParams.  # noqa: E501


        :return: The encoded_configuration of this BTShareParams.  # noqa: E501
        :rtype: str
        """
        return self._encoded_configuration

    @encoded_configuration.setter
    def encoded_configuration(self, encoded_configuration):
        """Sets the encoded_configuration of this BTShareParams.


        :param encoded_configuration: The encoded_configuration of this BTShareParams.  # noqa: E501
        :type: str
        """

        self._encoded_configuration = encoded_configuration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTShareParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from onshape_client.compatible_imports import HTTPServer, HTTPHandler, sendable
import webbrowser


def start_server(authorization_callback, open_grant_authorization_page_callback):
    """
    :param authorization_callback: The function to call once with the authorization URL response
    :param startup_callback: The function to call when the server starts - for example opening a webpage
    :return:
    """
    ServerClass = MakeServerClass(open_grant_authorization_page_callback)
    server = ServerClass(('localhost', 9000), MakeHandlerWithCallbacks(authorization_callback))
    server.serve_forever()


def MakeServerClass(open_grant_authorization_page_callback):
    class OAuth2RedirectServer(HTTPServer, object):

        def server_activate(self):
            super(OAuth2RedirectServer, self).server_activate()
            open_grant_authorization_page_callback()

    return OAuth2RedirectServer


def MakeHandlerWithCallbacks(authorization_callback):
    class OAuth2RedirectHandler(HTTPHandler):
        def do_GET(self):

            try:
                # Say we are at an https port so that OAuth package doesn't complain. This isn't a security concern because
                # it is just so that the authorization code is correctly parsed.
                authorization_callback("https://localhost" + self.path)
                self.send_response(200)
                self.send_header('Content-type', 'text/html')
                self.end_headers()
                content = '''
                            <html><head><title>Success!</title></head>
                            <body><p>You successfully authorized the application, and your authorization url is: {}</p>
                            <p>You may close this tab.</p>
                            </body></html>
                            '''.format(self.path)
                self.wfile.write(sendable(content))
            except BaseException as e:
                self.send_response(500)
                self.send_header('Content-type', 'text/html')
                self.end_headers()
                content = '''
                            <html><head><title>Error!</title></head>
                            <body><p>Something happened and here is what we know: {}</p>
                            <p>You may close this tab.</p>
                            </body></html>
                            '''.format(e)
                self.wfile.write(sendable(content))

            import threading
            assassin = threading.Thread(target=self.server.shutdown)
            assassin.daemon = True
            assassin.start()

    return OAuth2RedirectHandler
